==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PasswordDictionary.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordDictionaryCommon;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Weak password dictionary lookup settings
 */
@ApiModel(description = "Weak password dictionary lookup settings")
@JsonPropertyOrder({ PasswordDictionary.JSON_PROPERTY_COMMON })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordDictionary implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_COMMON = "common";
    private PasswordDictionaryCommon common;

    public PasswordDictionary() {
    }

    public PasswordDictionary common(PasswordDictionaryCommon common) {

        this.common = common;
        return this;
    }

    /**
     * Get common
     *
     * @return common
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_COMMON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordDictionaryCommon getCommon() {
        return common;
    }

    @JsonProperty(JSON_PROPERTY_COMMON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCommon(PasswordDictionaryCommon common) {
        this.common = common;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordDictionary passwordDictionary = (PasswordDictionary) o;
        return Objects.equals(this.common, passwordDictionary.common);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(common);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordDictionary {\n");
        sb.append("    common: ").append(toIndentedString(common)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/PasswordDictionary.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordDictionaryCommon;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Weak password dictionary lookup settings
 */
@ApiModel(description = "Weak password dictionary lookup settings")
@JsonPropertyOrder({ PasswordDictionary.JSON_PROPERTY_COMMON })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordDictionary implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_COMMON = "common";
    private PasswordDictionaryCommon common;

    public PasswordDictionary() {
    }

    public PasswordDictionary common(PasswordDictionaryCommon common) {

        this.common = common;
        return this;
    }

    /**
     * Get common
     *
     * @return common
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_COMMON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordDictionaryCommon getCommon() {
        return common;
    }

    @JsonProperty(JSON_PROPERTY_COMMON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCommon(PasswordDictionaryCommon common) {
        this.common = common;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordDictionary passwordDictionary = (PasswordDictionary) o;
        return Objects.equals(this.common, passwordDictionary.common);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(common);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordDictionary {\n");
        sb.append("    common: ").append(toIndentedString(common)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
